# seven_top

## 天志互联Python淘宝top库

### 1.0.27 更新内容
* 增加新的api
ChattingPlatformNewuserUserGroupListRequest
ChattingPlatformNewuserUserJoinGroupInfoRequest
MiniappWidgetTemplateInstanceQueryRequest
MiniappWidgetTemplateInstanceUpdateRequest
MiniappWidgetTemplateInstantiateRequest
SellercenterSubusersPageRequest
SubusersInfoQueryRequest
SubusersPageRequest
SubusersSubaccountSearchRequest

### 1.0.26 更新内容
* 增加新的api
CrmPointAvailableGetPrivyCpRequest
CrmPointAvailableGetRequest
CrmPointChangePrivyRequest
CrmPointChangeRequest

### 1.0.25 更新内容
* 增加新的api
CrmMemberIdentityGetPrivyRequest
MiniappDistributionOrderPrecreateRequest
MiniappDistributionOrderItemsAllBindRequest
MiniappDistributionOrderGetRequest
MiniappDistributionMaterialUpdateRequest
MiniappDistributionMaterialGetRequest
MiniappDistributionMaterialDeleteRequest
MiniappDistributionMaterialCreateRequest
JstSmsTemplateReportRequest
JstSmsTemplateQueryRequest
JstSmsTemplateModifyRequest
JstSmsTemplateDeleteRequest
JstSmsTemplateCreateRequest
JstSmsSignnameReportRequest
JstSmsSignnameQueryRequest
JstSmsSignnameModifyRequest
JstSmsSignnameDeleteRequest
JstSmsSignnameCreateRequest

### 1.0.24 更新内容
* 增加新的api
AlibabaLafiteSellerActivityListRequest
AlibabaLatourStrategyShowRequest
AlibabaLafiteSellerBenefitListRequest
AlibabaLatourStrategyIssueRequest

### 1.0.23 更新内容
* 增加新的api

### 1.0.21 更新内容
* 增加新的api
MiniappDistributionOrderCreateRequest
MiniappDistributionOrderItemsBindRequest
OpentradeCreateOrderRequest
* 更新部分接口

### 1.0.19 更新内容
* 增加新的api
JstSmsOaidMessageSendRequest
MarketingPromotionKfcRequest
MiniappCloudFunctionInvokeRequest
PromotionActivityGetRequest
PromotionCouponsGetRequest
PromotionLimitdiscountDetailGetRequest
PromotionLimitdiscountGetRequest
PromotionMealGetRequest

### 1.0.18 更新内容
* 增加新的api
RefundGetRequest
RefundRefuseRequest
RefundsApplyGetRequest
RefundMessageAddRequest
RefundMessagesGetRequest
RefundsReceiveGetRequest

### 1.0.17 更新内容
* 增加新的api
OpentradeGroupActivtiyQueryRequest
OpentradeGroupDetailRequest
OpentradeGroupJoinRequest
OpentradeGroupMemberInfoRequest
OpentradeGroupMemberInfosRequest
OpentradeGroupOpenRequest
OpentradeGroupOrderRequest
OpentradeGroupQueryRequest
OpentradeGroupSyncRequest
OpentradeSpecialItemsBindRequest
OpentradeSpecialItemsQueryRequest
OpentradeSpecialItemsUnbindRequest
OpentradeSpecialRuleUpdateRequest
OpentradeSpecialUsersMarkRequest
OpentradeSpecialUsersQueryRequest

### 1.0.16 更新内容
* 增加新的api
OpentradeToolsItemsBindRequest.py
OpentradeToolsItemsQueryRequest.py
OpentradeToolsItemsUnbindRequest.py
JstSmsTaskCreateRequest.py

### 1.0.15 更新内容
* 更新MiniappTemplateInstantiateRequest新增参数self.alias = None

### 1.0.14 更新内容
* 增加新的api
TraderatesGetRequest.py
TraderateImprImprwordsGetRequest.py
TmallTraderateItemtagsGetRequest.py
TmallTraderateFeedsGetRequest.py
MiniappTemplateRollbackRequest.py
MiniappTemplateOfflineappRequest.py
MiniappShorturlCreateRequest.py
JstSmsMessageShorturlQueryRequest.py
JstSmsMessageShorturlCreateRequest.py
JstSmsMessageDirectBatchsendRequest.py
MiniappCloudMongoInsertRequest.py
MiniappCloudMongoUpdateRequest.py

### 1.0.12 更新内容
* 更新oss2版本
oss2 >= 2.13.0

### 1.0.11 更新内容
* 增加新的api
AlibabaBenefitDrawRequest.py
AlibabaBenefitQueryRequest.py
AlibabaBenefitSendRequest.py
AlibabaBeneiftDrawRequest.py

### 1.0.10 更新内容
* 增加新的api
MiniappCloudMongoInsertRequest.py
MiniappCloudMongoUpdateRequest.py

### 1.0.9 更新内容
* 增加新的api
CrmMemberIdentityGetRequest.py
CrmMemberJoinurlGetRequest.py

### 1.0.8 更新内容
* 增加新的api

### 1.0.5 更新内容
* 淘宝top库初始工程